==> haskell-skylighting-core-0.7.7-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting-core
version: 0.7.7
id: skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K
key: skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K
license: BSD-3-Clause
copyright: (C) 2016-2018 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.
category: Text
abi: 552953f94cf7be29c1a0434ee36208a4
exposed: True
exposed-modules:
    Skylighting.Core Skylighting.Format.ANSI Skylighting.Format.HTML
    Skylighting.Format.LaTeX Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types
import-dirs: /usr/lib/ghc-8.6.4/site-local/skylighting-core-0.7.7
library-dirs: /usr/lib/ghc-8.6.4/site-local/skylighting-core-0.7.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/skylighting-core-0.7.7
hs-libraries: HSskylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K
depends:
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC binary-0.8.6.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    colour-2.3.4-BYzTQyKoQ9LK29pbkBo2SY containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hxt-9.3.1.16-KGFpujsr1gF9i7MtYNq3HM mtl-2.2.2
    regex-pcre-0.94.4-6OiTOSawdaJqgEwlhRSRS
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji text-1.2.3.1
    transformers-0.5.6.2 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock
haddock-html: /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-core-0.7.7-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting-core
version: 0.7.7
id: skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3
key: skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3
license: BSD-3-Clause
copyright: (C) 2016-2018 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.
category: Text
abi: 2bae11f736330ee1b4f65bfc94b6352a
exposed: True
exposed-modules:
    Skylighting.Core Skylighting.Format.ANSI Skylighting.Format.HTML
    Skylighting.Format.LaTeX Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types
import-dirs: /usr/lib/ghc-8.6.4/site-local/skylighting-core-0.7.7
library-dirs: /usr/lib/ghc-8.6.4/site-local/skylighting-core-0.7.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/skylighting-core-0.7.7
hs-libraries: HSskylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3
depends:
    aeson-1.4.2.0-QHLwhPMHVB663aXnGqoMq
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC binary-0.8.6.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    colour-2.3.4-BYzTQyKoQ9LK29pbkBo2SY containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hxt-9.3.1.16-KGFpujsr1gF9i7MtYNq3HM mtl-2.2.2
    regex-pcre-0.94.4-6OiTOSawdaJqgEwlhRSRS
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji text-1.2.3.1
    transformers-0.5.6.2 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock
haddock-html: /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
